// ignore_for_file: constant_identifier_names

import 'dart:async';
import 'package:fawry_sdk/fawry_sdk_platform_interface.dart';
import 'package:fawry_sdk/model/fawry_launch_model.dart';
import 'package:flutter/services.dart';

class FawrySDK extends FawrySdkPlatformInterface {
  FawrySDK._();

  static FawrySDK instance = FawrySDK._();

  // Error codes
  static const String _CODE_PAYMENT_FAILED = "1";

  // Event channel name for callback results
  static const String EVENT_CHANNEL_NAME = "event.channel/fawry_sdk";

  // Response codes
  static const String RESPONSE_SUCCESS = "100";
  static const String RESPONSE_ERROR = "101";
  static const String RESPONSE_PAYMENT_COMPLETED = "102";

  // Supported languages
  static const String LANGUAGE_ARABIC = "ARABIC";
  static const String LANGUAGE_ENGLISH = "ENGLISH";

  // Event channel for callback results
  final EventChannel _eventChannelCallbackResult =
      const EventChannel(EVENT_CHANNEL_NAME);

  @override
  Future<bool> startPayment ({
    required FawryLaunchModel launchModel,
    required String baseURL,
    required String lang,
  }) async {
    try {
      return await FawrySdkPlatformInterface.instance.startPayment(
        launchModel: launchModel,
        baseURL: baseURL,
        lang: lang,
      );
    } on PlatformException catch (e) {
      if (e.code == _CODE_PAYMENT_FAILED) {
        throw "Payment Failed: $_CODE_PAYMENT_FAILED. Message: ${e.message}.";
      }
      throw "Unknown Error: Error ->  ${e.message}";
    } catch (e) {
      throw "Error Occurred: Message: $e";
    }
  }

  @override
  Future<bool> openCardsManager ({
    required FawryLaunchModel launchModel,
    required String baseURL,
    required String lang,
  }) async {
    try {
      return await FawrySdkPlatformInterface.instance.openCardsManager(
        launchModel: launchModel,
        baseURL: baseURL,
        lang: lang,
      );
    } on PlatformException catch (e) {
      if (e.code == _CODE_PAYMENT_FAILED) {
        throw "Payment Failed: $_CODE_PAYMENT_FAILED. Message: ${e.message}.";
      }
      throw "Unknown Error: Error ->  ${e.message}";
    } catch (e) {
      throw "Error Occurred: Message: $e";
    }
  }

  

  // Stream for receiving callback results
  Stream callbackResultStream() {
    return _eventChannelCallbackResult.receiveBroadcastStream();
  }
}
